core

package
v0.0.0-...-5ec08a6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 4, 2026 License: Apache-2.0 Imports: 24 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type BackupPlugin

type BackupPlugin struct {
	*plugtypes.BackupOptions
	// contains filtered or unexported fields
}

BackupPlugin is a backup item action plugin for Hypershift common objects.

func NewBackupPlugin

func NewBackupPlugin(logger logrus.FieldLogger) (*BackupPlugin, error)

NewBackupPlugin instantiates BackupPlugin.

func (*BackupPlugin) AppliesTo

func (p *BackupPlugin) AppliesTo() (velero.ResourceSelector, error)

func (*BackupPlugin) Execute

Execute allows the ItemAction to perform arbitrary logic with the item being backed up,

func (*BackupPlugin) Name

func (p *BackupPlugin) Name() string

Name is required to implement the interface, but the Velero pod does not delegate this method -- it's used to tell velero what name it was registered under. The plugin implementation must define it, but it will never actually be called.

type RestoreOptions

type RestoreOptions struct {
	// contains filtered or unexported fields
}

type RestorePlugin

type RestorePlugin struct {
	*plugtypes.RestoreOptions
	// contains filtered or unexported fields
}

RestorePlugin is a plugin to restore hypershift resources.

func NewRestorePlugin

func NewRestorePlugin(logger logrus.FieldLogger) (*RestorePlugin, error)

NewRestorePlugin instantiates RestorePlugin.

func (*RestorePlugin) AppliesTo

func (p *RestorePlugin) AppliesTo() (velero.ResourceSelector, error)

func (*RestorePlugin) Name

func (p *RestorePlugin) Name() string

Directories

Path Synopsis

Jump to